==> exampledata-4.1.2.jar: META-INF/resources/frontend/data-generator-types.ts <==
export enum DataType {
  ID = 'ID',
  UUID = 'UUID',
  FirstName = 'FIRST_NAME',
  LastName = 'LAST_NAME',
  FullName = 'FULL_NAME',
  Email = 'EMAIL',
  Domain = 'DOMAIN',
  Occupation = 'OCCUPATION',
  CompanyName = 'COMPANY_NAME',
  IBAN = 'IBAN',
  TransactionStatus = 'TRANSACTION_STATUS',
  ProfilePictureURL = 'PROFILE_PICTURE_URL',
  AmountOfMoney = 'AMOUNT_OF_MONEY',
  DateOfBirth = 'DATE_OF_BIRTH',
  PhoneNumber = 'PHONE_NUMBER',
  City = 'CITY',
  State = 'STATE',
  Country = 'COUNTRY',
  ZipCode = 'ZIP_CODE',
  Address = 'ADDRESS',
  BookTitle = 'BOOK_TITLE',
  BookTitlePrefix = 'BOOK_TITLE_PREFIX',
  BookTitleSuffix = 'BOOK_TITLE_SUFFIX',
  BookImageUrl = 'BOOK_IMAGE_URL',
  BookImageBackground = 'BOOK_IMAGE_BACKGROUND',
  BookGenre = 'BOOK_GENRE',
  Price = 'PRICE',
  Word = 'WORD',
  TwoWords = 'TWO_WORDS',
  Sentence = 'SENTENCE',
  Ean13 = 'EAN13',
  NumberUpTo10 = 'NUMBER_UP_TO_10',
  NumberUpTo100 = 'NUMBER_UP_TO_100',
  NumberUpTo1000 = 'NUMBER_UP_TO_1000',
  NumberUpTo10000 = 'NUMBER_UP_TO_10000',
  FoodProductName = 'FOOD_PRODUCT_NAME',
  FoodProductImage = 'FOOD_PRODUCT_IMAGE',
  FoodProductEan = 'FOOD_PRODUCT_EAN',
  Boolean_50_50 = 'BOOLEAN_50_50',
  Boolean_90_10 = 'BOOLEAN_90_10',
  Boolean_10_90 = 'BOOLEAN_10_90',
  DateLast10Years = 'DATE_LAST_10_YEARS',
  DateLast1Year = 'DATE_LAST_1_YEAR',
  DateLast30Days = 'DATE_LAST_30_DAYS',
  DateLast7days = 'DATE_LAST_7_DAYS',
  DateNext10Years = 'DATE_NEXT_10_YEARS',
  DateNext1Year = 'DATE_NEXT_1_YEAR',
  DateNext30Days = 'DATE_NEXT_30_DAYS',
  DateNext7days = 'DATE_NEXT_7_DAYS',
  DateTimeLast10Years = 'DATETIME_LAST_10_YEARS',
  DateTimeLast1Year = 'DATETIME_LAST_1_YEAR',
  DateTimeLast30Days = 'DATETIME_LAST_30_DAYS',
  DateTimeLast7days = 'DATETIME_LAST_7_DAYS',
  DateTimeNext10Years = 'DATETIME_NEXT_10_YEARS',
  DateTimeNext1Year = 'DATETIME_NEXT_1_YEAR',
  DateTimeNext30Days = 'DATETIME_NEXT_30_DAYS',
  DateTimeNext7days = 'DATETIME_NEXT_7_DAYS',
  TimeRandom = 'TIME_RANDOM',
  TimeHours = 'TIME_HOURS',
}

==> exampledata-6.0.0.jar: META-INF/resources/frontend/data-generator-types.ts <==
export enum DataType {
  ID = 'ID',
  UUID = 'UUID',
  FirstName = 'FIRST_NAME',
  LastName = 'LAST_NAME',
  FullName = 'FULL_NAME',
  Email = 'EMAIL',
  Domain = 'DOMAIN',
  Occupation = 'OCCUPATION',
  CompanyName = 'COMPANY_NAME',
  IBAN = 'IBAN',
  TransactionStatus = 'TRANSACTION_STATUS',
  ProfilePictureURL = 'PROFILE_PICTURE_URL',
  AmountOfMoney = 'AMOUNT_OF_MONEY',
  DateOfBirth = 'DATE_OF_BIRTH',
  PhoneNumber = 'PHONE_NUMBER',
  City = 'CITY',
  State = 'STATE',
  Country = 'COUNTRY',
  ZipCode = 'ZIP_CODE',
  Address = 'ADDRESS',
  BookTitle = 'BOOK_TITLE',
  BookTitlePrefix = 'BOOK_TITLE_PREFIX',
  BookTitleSuffix = 'BOOK_TITLE_SUFFIX',
  BookImageUrl = 'BOOK_IMAGE_URL',
  BookImageData = 'BOOK_IMAGE_DATA',
  BookImageBackground = 'BOOK_IMAGE_BACKGROUND',
  BookImageFileNames = 'BOOK_IMAGE_FILE_NAMES',
  BookGenre = 'BOOK_GENRE',
  Price = 'PRICE',
  Word = 'WORD',
  TwoWords = 'TWO_WORDS',
  Sentence = 'SENTENCE',
  Ean13 = 'EAN13',
  NumberUpTo10 = 'NUMBER_UP_TO_10',
  NumberUpTo100 = 'NUMBER_UP_TO_100',
  NumberUpTo1000 = 'NUMBER_UP_TO_1000',
  NumberUpTo10000 = 'NUMBER_UP_TO_10000',
  FoodProductName = 'FOOD_PRODUCT_NAME',
  FoodProductImage = 'FOOD_PRODUCT_IMAGE',
  FoodProductImageBytes = 'FOOD_PRODUCT_IMAGE_BYTES',
  FoodProductEan = 'FOOD_PRODUCT_EAN',
  Boolean_50_50 = 'BOOLEAN_50_50',
  Boolean_90_10 = 'BOOLEAN_90_10',
  Boolean_10_90 = 'BOOLEAN_10_90',
  DateLast10Years = 'DATE_LAST_10_YEARS',
  DateLast1Year = 'DATE_LAST_1_YEAR',
  DateLast30Days = 'DATE_LAST_30_DAYS',
  DateLast7days = 'DATE_LAST_7_DAYS',
  DateNext10Years = 'DATE_NEXT_10_YEARS',
  DateNext1Year = 'DATE_NEXT_1_YEAR',
  DateNext30Days = 'DATE_NEXT_30_DAYS',
  DateNext7days = 'DATE_NEXT_7_DAYS',
  DateTimeLast10Years = 'DATETIME_LAST_10_YEARS',
  DateTimeLast1Year = 'DATETIME_LAST_1_YEAR',
  DateTimeLast30Days = 'DATETIME_LAST_30_DAYS',
  DateTimeLast7days = 'DATETIME_LAST_7_DAYS',
  DateTimeNext10Years = 'DATETIME_NEXT_10_YEARS',
  DateTimeNext1Year = 'DATETIME_NEXT_1_YEAR',
  DateTimeNext30Days = 'DATETIME_NEXT_30_DAYS',
  DateTimeNext7days = 'DATETIME_NEXT_7_DAYS',
  TimeRandom = 'TIME_RANDOM',
  TimeHours = 'TIME_HOURS',
}
